NAME

WWW::Crawl4AI::Strategy::Stealth - Crawl4AI strategy with enable_stealth and randomized fingerprint

VERSION

version 0.001

DESCRIPTION

Turns on Crawl4AI's enable_stealth (Playwright-stealth-style fingerprint adjustment) and a randomized user agent. Aimed at sites with light bot protection that reject a vanilla headless browser.

name

crawl4ai_stealth.

cost_class

stealth.

SUPPORT

Issues

Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-www-crawl4ai/issues.

CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

AUTHOR

Torsten Raudssus <torsten@raudssus.de> https://raudss.us/

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Torsten Raudssus.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.