NAME

WWW::Link::Reporter::Text - Report on status of links in plain text

SYNOPSIS

use WWW::Link;
use WWW::Link::Reporter::Text;

$link=new WWW::Link;

#over time do things to the link ......

$reporter = new WWW::Link::Reporter::Text
$reporter->examine($link)

DESCRIPTION

This is a very simple class derived from WWW::Link::Reporter which provides a report on the status of links in text for easy reading. Nothing much can be done other than read it.