NAME
WWW::PayPal::API::Products - PayPal Catalogs Products API (v1)
VERSION
version 0.001
SYNOPSIS
my $product = $pp->products->create(
name => 'Monthly VIP membership',
type => 'SERVICE', # or 'PHYSICAL' / 'DIGITAL'
category => 'SOFTWARE', # optional
description => 'Unlocks the VIP area',
);
my $same = $pp->products->get($product->id);
DESCRIPTION
Controller for PayPal's Catalogs Products API. A product is the abstract thing you sell; plans and subscriptions reference it by ID. Typically you create a product once at setup time and reuse it.
create
my $product = $pp->products->create(
name => 'Foo', type => 'SERVICE', category => 'SOFTWARE',
);
Creates a product. type is one of PHYSICAL, DIGITAL, SERVICE.
get
my $product = $pp->products->get($id);
list
my $products = $pp->products->list(page_size => 20);
Returns an ArrayRef of WWW::PayPal::Product.
SUPPORT
Issues
Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-www-paypal/issues.
CONTRIBUTING
Contributions are welcome! Please fork the repository and submit a pull request.
AUTHOR
Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/
COPYRIGHT AND LICENSE
This software is copyright (c) 2026 by Torsten Raudssus.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.