NAME
WWW::PayPal::Product - PayPal Catalogs Product entity
VERSION
version 0.001
DESCRIPTION
Wrapper around a PayPal catalog product JSON object.
data
Raw decoded JSON for the product.
id
Product ID (e.g. PROD-XXX...). Pass this to "create" in WWW::PayPal::API::Plans.
name
type
PHYSICAL, DIGITAL, or SERVICE.
category
PayPal merchant category code, e.g. SOFTWARE.
description
create_time
update_time
SUPPORT
Issues
Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-www-paypal/issues.
CONTRIBUTING
Contributions are welcome! Please fork the repository and submit a pull request.
AUTHOR
Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/
COPYRIGHT AND LICENSE
This software is copyright (c) 2026 by Torsten Raudssus.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.