NAME
WWW::PayPal::Refund - PayPal Payments v2 refund entity
VERSION
version 0.001
SYNOPSIS
my $refund = $pp->payments->refund($capture_id,
amount => { currency_code => 'EUR', value => '5.00' },
);
print $refund->id, "\n";
print $refund->status, "\n";
print $refund->amount, "\n";
print $refund->currency, "\n";
DESCRIPTION
Wrapper around a PayPal refund JSON object, as returned by "refund" in WWW::PayPal::API::Payments and "get_refund" in WWW::PayPal::API::Payments.
data
Raw decoded JSON for the refund.
id
Refund ID.
status
Refund status — CANCELLED, PENDING, FAILED, COMPLETED.
amount
String amount, e.g. "5.00".
currency
Currency code, e.g. "EUR".
note
The note_to_payer that was included with the refund, if any.
SEE ALSO
SUPPORT
Issues
Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-www-paypal/issues.
CONTRIBUTING
Contributions are welcome! Please fork the repository and submit a pull request.
AUTHOR
Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/
COPYRIGHT AND LICENSE
This software is copyright (c) 2026 by Torsten Raudssus.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.